@@ -726,7 +726,7 @@ server = function(input, output, session) {
     if (!is.null(input$spectrogram_hover) & !is.null(myPars$spec)) {
       myPars$spectrogram_hover = input$spectrogram_hover
       cursor_hz = myPars$spectrogram_hover$y * 1000
-      cursor_notes = soundgen::notesDict$note[round(HzToSemitones(cursor_hz)) + 1]
+      cursor_notes = soundgen::HzToNotes(cursor_hz)
       myPars$spectrogram_hover$freq = paste0(
         round(myPars$spectrogram_hover$y * 1000), ' Hz (',
         cursor_notes, ')')
@@ -963,7 +963,7 @@ server = function(input, output, session) {
       myPars$spectrum_hover = data.frame(x = input$spectrum_hover$x,
                                          y = input$spectrum_hover$y)
       cursor_hz = round(input$spectrum_hover$x * 1000)
-      cursor_notes = soundgen::notesDict$note[round(HzToSemitones(cursor_hz)) + 1]
+      cursor_notes = soundgen::HzToNotes(cursor_hz)
       myPars$spectrum_hover$cursor = paste0(cursor_hz, 'Hz (', cursor_notes, ')')
 
       pf_idx = which.min(abs(myPars$spectrum_hover$x -
@@ -971,7 +971,7 @@ server = function(input, output, session) {
       myPars$spectrum_hover$pa =myPars$spectrum$ampl[myPars$spectrum_peaks[pf_idx]]
       myPars$spectrum_hover$pf = myPars$spectrum$freq[myPars$spectrum_peaks[pf_idx]]
       nearest_peak_hz = round(myPars$spectrum_hover$pf * 1000)
-      nearest_peak_notes = soundgen::notesDict$note[round(HzToSemitones(nearest_peak_hz)) + 1]
+      nearest_peak_notes = soundgen::HzToNotes(nearest_peak_hz)
       myPars$spectrum_hover$peak = paste0(nearest_peak_hz, ' Hz (',
                                           nearest_peak_notes, ')')
     }
